@@ -8,9 +8,9 @@ use Log::ger;
 use App::orgadb::Common;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-15'; # DATE
+our $DATE = '2022-10-16'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 our %SPEC;
 
@@ -42,15 +42,15 @@ sub _select_single {
     my $res = [200, "OK", ""];
     my @outputted_field_values;
 
-    my @parsed_default_formatter_rules;
+    my @parsed_field_value_formatter_rules;
 
-    my $formatter;
-  SET_FORMATTERS:
+    my $field_value_formatter_from_args;
+  SET_FIELD_VALUE_FORMATTERS_FROM_ARGS:
     {
-        last if $args{no_formatters};
-        last unless $args{formatters} && @{ $args{formatters} };
+        last if $args{no_field_value_formatters};
+        last unless $args{field_value_formatters} && @{ $args{field_value_formatters} };
         my @filter_names;
-        for my $f (@{ $args{formatters} }) {
+        for my $f (@{ $args{field_value_formatters} }) {
             if ($f =~ /\A\[/) {
                 require JSON::PP;
                 $f = JSON::PP::decode_json($f);
@@ -68,7 +68,7 @@ sub _select_single {
             push @filter_names, $f;
         }
         require Data::Sah::Filter;
-        $formatter = Data::Sah::Filter::gen_filter(
+        $field_value_formatter_from_args = Data::Sah::Filter::gen_filter(
             filter_names => \@filter_names,
             return_type => 'str_errmsg+val',
         );
@@ -241,17 +241,17 @@ sub _select_single {
                         }
                     }
 
-                    my $default_formatter;
-                  SET_DEFAULT_FORMATTERS:
+                    my $field_value_formatter_from_rules;
+                  SET_FIELD_VALUE_FORMATTERS_FROM_RULES:
                     {
-                        last if $args{no_formatters};
-                        last if $formatter;
-                        last unless $args{default_formatter_rules} && @{ $args{default_formatter_rules} };
+                        last if $args{no_field_value_formatters};
+                        last if $field_value_formatter_from_args;
+                        last unless $args{field_value_formatter_rules} && @{ $args{field_value_formatter_rules} };
 
-                        my $default_formatters = [];
-                        unless (@parsed_default_formatter_rules) {
+                        my $field_value_formatters_from_rules = [];
+                        unless (@parsed_field_value_formatter_rules) {
                             my $i = -1;
-                            for my $r0 (@{ $args{default_formatter_rules} }) {
+                            for my $r0 (@{ $args{field_value_formatter_rules} }) {
                                 $i++;
                                 my $r;
                                 if (!ref($r0) && $r0 =~ /\A\{/) {
@@ -292,60 +292,60 @@ sub _select_single {
                                         return_type => 'str_errmsg+val',
                                     );
                                 } else {
-                                    die "Default formatting rules [$i] does not have non-empty formatters: %s", $r;
+                                    die "Field value formatting rules [$i] does not have non-empty formatters: %s", $r;
                                 }
-                                push @parsed_default_formatter_rules, $r;
+                                push @parsed_field_value_formatter_rules, $r;
                             }
-                            #log_error "parsed_default_formatter_rules=%s", \@parsed_default_formatter_rules;
-                        } # set @parsed_default_formatter_rules
+                            #log_error "parsed_field_value_formatter_rules=%s", \@parsed_field_value_formatter_rules;
+                        } # set @parsed_field_value_formatter_rules
 
                         # do the filtering
                         my $i = -1;
                       RULE:
-                        for my $r (@parsed_default_formatter_rules) {
+                        for my $r (@parsed_field_value_formatter_rules) {
                             $i++;
                             my $matches = 1;
                             if (defined $r->{field_name_matches}) {
                                 $field_name0 =~ $r->{field_name_matches} or do {
                                     $matches = 0;
-                                    log_trace "Skipping default_formatter_rules[%d]: field_name_matches %s doesn't match %s", $i, $r->{field_name_matches}, $field_name0;
+                                    log_trace "Skipping field_value_formatter_rules[%d]: field_name_matches %s doesn't match %s", $i, $r->{field_name_matches}, $field_name0;
                                     next RULE;
                                 };
                             }
                             if (defined $r->{hide_field_name}) {
                                 if ($args{hide_field_name} xor $r->{hide_field_name}) {
                                     $matches = 0;
-                                    log_trace "Skipping default_formatter_rules[%d]: hide_field_name condition (%s) doesn't match actual hide_field_name option (%s)", $i, ($r->{hide_field_name} ? 'true':'false'), ($args{hide_field_name} ? 'true':'false');
+                                    log_trace "Skipping field_value_formatter_rules[%d]: hide_field_name condition (%s) doesn't match actual hide_field_name option (%s)", $i, ($r->{hide_field_name} ? 'true':'false'), ($args{hide_field_name} ? 'true':'false');
                                     next RULE;
                                 }
                             }
-                            log_trace "Adding formatters from default_formatter_rules[%d] (%s) for field name %s", $i, $r->{formatters}, $field_name0;
-                            push @$default_formatters, $r->{formatter};
+                            log_trace "Adding field value formatters from field_value_formatter_rules[%d] (%s) for field name %s", $i, $r->{formatters}, $field_name0;
+                            push @$field_value_formatters_from_rules, $r->{formatter};
                         }
                         # combine default formatters
-                        last unless @$default_formatters;
-                        if (@$default_formatters > 1) {
-                            $default_formatter = sub {
+                        last unless @$field_value_formatters_from_rules;
+                        if (@$field_value_formatters_from_rules > 1) {
+                            $field_value_formatter_from_rules = sub {
                                 my $val = shift;
                                 my $res;
-                                for my $i (0 .. $#{$default_formatters}) {
-                                    $res = $default_formatters->[$i]->($val);
+                                for my $i (0 .. $#{$field_value_formatters_from_rules}) {
+                                    $res = $field_value_formatters_from_rules->[$i]->($val);
                                     return $res if $res->[0];
                                     $val = $res->[1];
                                 }
                                 $res;
                             };
                         } else {
-                            $default_formatter = $default_formatters->[0];
+                            $field_value_formatter_from_rules = $field_value_formatters_from_rules->[0];
                         }
-                    } # SET_DEFAULT_FORMATTERS
+                    } # SET_FIELD_VALUE_FORMATTERS_FROM_RULES
 
                     my $field_value0 = $field->children_as_string;
                     my ($prefix, $field_value, $suffix) = $field_value0 =~ /\A(\s+)(.*?)(\s*)\z/s;
-                    if ($formatter || $default_formatter) {
-                        my ($ferr, $fres) = @{ ($formatter || $default_formatter)->($field_value) };
+                    if ($field_value_formatter_from_args || $field_value_formatter_from_rules) {
+                        my ($ferr, $fres) = @{ ($field_value_formatter_from_args || $field_value_formatter_from_rules)->($field_value) };
                         if ($ferr) {
-                            log_warn "Formatting error: field value=%s, errmsg=%s", $field_value, $ferr;
+                            log_warn "Field value formatting error: field value=%s, errmsg=%s", $field_value, $ferr;
                             $field_value = "$field_value # CAN'T FORMAT: $ferr";
                         } else {
                             $field_value = $fres;
@@ -478,7 +478,7 @@ App::orgadb - An opinionated Org addressbook toolset
 
 =head1 VERSION
 
-This document describes version 0.012 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-15.
+This document describes version 0.013 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-16.
 
 =head1 SYNOPSIS
 
@@ -535,34 +535,43 @@ Whether to use color.
 
 Return just the number of matching entries instead of showing them.
 
-=item * B<default_formatter_rules> => I<array[hash]>
+=item * B<detail> => I<bool>
 
-Specify conditional default formatters, as an array of hashes. Each element is a
-rule that is specified as a hash containing condition keys and formatters keys.
-If all conditions are met then the formatters will be applied. The rules will be
-tested when each field is about to be outputted. Multiple rules can match and
-the matching rules' formatters are all applied in succession.
+(No description)
 
-Note that this option will be overridden by the C<--formatter> or the
-C<--no-formatters> (C<-F>) option.
+=item * B<entry> => I<str_or_re>
 
-Default formatters are best specified in the configuration as opposed to on the
+Find entry by string or regex search against its title.
+
+=item * B<field_value_formatter_rules> => I<array[hash]>
+
+Specify field value formatters to use when conditions are met, specified as an
+array of hashes. Each element is a rule that is as a hash containing condition
+keys and formatters keys. If all conditions are met then the formatters will be
+applied. The rules will be tested when each field is about to be outputted.
+Multiple rules can match and the matching rules' formatters are all applied in
+succession.
+
+Note that this option will be overridden by the C<--field-value-formatter>
+(C<-fvfmt>) or the C<--no-field-value-formatters> (C<-F>) option.
+
+The rules are best specified in the configuration as opposed to on the
 command-line option. An example (the lines below are writen in configuration
 file in IOD syntax, as rows of JSON hashes):
 
  ; by default remove all comments in field values when 'hide_field_name'
  ; option is set (which usually means we want to copy paste things)
- default_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
+ field_value_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
  
  ; by default normalize phone numbers using Phone::format_phone_idn_nospace
  ; when 'hide_field_name' option is set (which usually means we want to copy
  ; paste things). e.g. '0812-1234-5678' becomes '+6281212345678'.
- default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+ field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
  
  ; but if 'hide_field_name' field is not set, normalize phone numbers using
  ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
  ; 5678').
- default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
+ field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
 
 Condition keys:
 
@@ -586,13 +595,27 @@ specifying formatter.
 
 =back
 
-=item * B<detail> => I<bool>
+=item * B<field_value_formatters> => I<array[str]>
 
-(No description)
+Add one or more formatters to display field value.
 
-=item * B<entry> => I<str_or_re>
+Specify one or more formatters to apply to the field value before displaying.
 
-Find entry by string or regex search against its title.
+A formatter is name of C<Data::Sah::Filter::perl::*> module, without the prefix.
+For example: C<Str::uc> will convert the field value to uppercase. Another
+formatter, C<Str::remove_comment> can remove comment.
+
+A formatter can have arguments, which is specified using this format:
+
+ [FORMATTER_NAME, {ARG1NAME => ARG1VAL, ...}]
+
+If formatter name begins with C<[> character, it will be parsed as JSON. Example:
+
+ ['Str::remove_comment', {'style':'cpp'}]
+
+Note that this option overrides C<--field-value-formatter-rules> but is
+overridden by the C<--no-field-value-formatters> (C<--raw-field-values>, C<-F>)
+option.
 
 =item * B<fields> => I<array[str_or_re]>
 
@@ -619,27 +642,6 @@ That is, it can search for a string (C<str>) or regex (C<re>) in the field name,
 and optionally also search for a string (C<str2>) or regex (C<re2>) in the field
 value.
 
-=item * B<formatters> => I<array[str]>
-
-Add one or more formatters to display field value.
-
-Specify one or more formatters to apply to the field value before displaying.
-
-A formatter is name of C<Data::Sah::Filter::perl::*> module, without the prefix.
-For example: C<Str::uc> will convert the field value to uppercase. Another
-formatter, C<Str::remove_comment> can remove comment.
-
-A formatter can have arguments, which is specified using this format:
-
- [FORMATTER_NAME, {ARG1NAME => ARG1VAL, ...}]
-
-If formatter name begins with C<[> character, it will be parsed as JSON. Example:
-
- ['Str::remove_comment', {'style':'cpp'}]
-
-Note that this option overrides C<--default-formatter-rules> but is overridden by
-the C<--no-formatters> (C<--raw-field-values>, C<-F>) option.
-
 =item * B<hide_category> => I<true>
 
 Do not show category.
@@ -652,12 +654,13 @@ Do not show entry headline.
 
 Do not show field names, just show field values.
 
-=item * B<no_formatters> => I<true>
+=item * B<no_field_value_formatters> => I<true>
 
-Do not apply any formatters to field value (overrides --formatter option).
+Do not apply formatters for field value (overrides --field-value-formatter option).
 
-Note that this option has higher precedence than C<--default-formatter-rules> or
-the C<--formatter> option.
+Note that this option has higher precedence than
+C<--default-field-value-formatter-rules> or the C<--field-value-formatter>
+(C<--fvfmt>) option.
 
 =item * B<num_entries> => I<uint>
 
