@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-15'; # DATE
+our $DATE = '2022-10-16'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 sub _heading_from_line {
     my $heading = shift;
@@ -319,50 +319,52 @@ our %argspecs_select = (
         summary => 'Return just the number of matching entries instead of showing them',
         schema => 'true*',
     },
-    no_formatters => {
-        summary => 'Do not apply any formatters to field value (overrides --formatter option)',
+    no_field_value_formatters => {
+        summary => 'Do not apply formatters for field value (overrides --field-value-formatter option)',
         schema => 'true*',
         description => <<'_',
 
-Note that this option has higher precedence than `--default-formatter-rules` or
-the `--formatter` option.
+Note that this option has higher precedence than
+`--default-field-value-formatter-rules` or the `--field-value-formatter`
+(`--fvfmt`) option.
 
 _
         cmdline_aliases => {raw_field_values=>{}, F=>{}},
         tags => ['category:output'],
     },
-    default_formatter_rules => {
+    field_value_formatter_rules => {
         'x.name.is_plural' => 1,
-        'x.name.singular' => 'default_formatter_rule',
+        'x.name.singular' => 'default_field_value_formatter_rule',
         schema => ['array*', of=>'hash*'],
         description => <<'_',
 
-Specify conditional default formatters, as an array of hashes. Each element is a
-rule that is specified as a hash containing condition keys and formatters keys.
-If all conditions are met then the formatters will be applied. The rules will be
-tested when each field is about to be outputted. Multiple rules can match and
-the matching rules' formatters are all applied in succession.
+Specify field value formatters to use when conditions are met, specified as an
+array of hashes. Each element is a rule that is as a hash containing condition
+keys and formatters keys. If all conditions are met then the formatters will be
+applied. The rules will be tested when each field is about to be outputted.
+Multiple rules can match and the matching rules' formatters are all applied in
+succession.
 
-Note that this option will be overridden by the `--formatter` or the
-`--no-formatters` (`-F`) option.
+Note that this option will be overridden by the `--field-value-formatter`
+(`-fvfmt`) or the `--no-field-value-formatters` (`-F`) option.
 
-Default formatters are best specified in the configuration as opposed to on the
+The rules are best specified in the configuration as opposed to on the
 command-line option. An example (the lines below are writen in configuration
 file in IOD syntax, as rows of JSON hashes):
 
     ; by default remove all comments in field values when 'hide_field_name'
     ; option is set (which usually means we want to copy paste things)
-    default_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
+    field_value_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
 
     ; by default normalize phone numbers using Phone::format_phone_idn_nospace
     ; when 'hide_field_name' option is set (which usually means we want to copy
     ; paste things). e.g. '0812-1234-5678' becomes '+6281212345678'.
-    default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+    field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
 
     ; but if 'hide_field_name' field is not set, normalize phone numbers using
     ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
     ; 5678').
-    default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
+    field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
 
 Condition keys:
 
@@ -381,9 +383,9 @@ Formatter keys:
 _
         tags => ['category:output'],
     },
-    formatters => {
+    field_value_formatters => {
         'x.name.is_plural' => 1,
-        'x.name.singular' => 'formatter',
+        'x.name.singular' => 'field_value_formatter',
         summary => 'Add one or more formatters to display field value',
         #schema => ['array*', of=>'perl::perl_sah_filter::modname_with_optional_args*'], ## doesn't work yet with Perinci::Sub::GetArgs::Argv
         schema => ['array*', of=>'str*'],
@@ -395,7 +397,7 @@ _
                 ns_prefix => 'Data::Sah::Filter::perl',
             );
         },
-        cmdline_aliases => {f=>{}},
+        cmdline_aliases => {fvfmt=>{}, f=>{}},
         tags => ['category:output'],
         description => <<'_',
 
@@ -413,8 +415,9 @@ If formatter name begins with `[` character, it will be parsed as JSON. Example:
 
  ['Str::remove_comment', {'style':'cpp'}]
 
-Note that this option overrides `--default-formatter-rules` but is overridden by
-the `--no-formatters` (`--raw-field-values`, `-F`) option.
+Note that this option overrides `--field-value-formatter-rules` but is
+overridden by the `--no-field-value-formatters` (`--raw-field-values`, `-F`)
+option.
 
 _
     },
@@ -464,7 +467,7 @@ App::orgadb::Common
 
 =head1 VERSION
 
-This document describes version 0.012 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-10-15.
+This document describes version 0.013 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-10-16.
 
 =head1 HOMEPAGE
 
