@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-15'; # DATE
+our $DATE = '2022-10-16'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use App::orgadb::Common;
 
@@ -127,7 +127,7 @@ App::orgadb::Select::Shell::Commands - orgadb-sel shell commands
 
 =head1 VERSION
 
-This document describes version 0.012 of App::orgadb::Select::Shell::Commands (from Perl distribution App-orgadb), released on 2022-10-15.
+This document describes version 0.013 of App::orgadb::Select::Shell::Commands (from Perl distribution App-orgadb), released on 2022-10-16.
 
 =for Pod::Coverage .+
 
@@ -208,34 +208,43 @@ only copy matching field values to clipboard.
 
 Return just the number of matching entries instead of showing them.
 
-=item * B<default_formatter_rules> => I<array[hash]>
+=item * B<detail> => I<bool>
 
-Specify conditional default formatters, as an array of hashes. Each element is a
-rule that is specified as a hash containing condition keys and formatters keys.
-If all conditions are met then the formatters will be applied. The rules will be
-tested when each field is about to be outputted. Multiple rules can match and
-the matching rules' formatters are all applied in succession.
+(No description)
 
-Note that this option will be overridden by the C<--formatter> or the
-C<--no-formatters> (C<-F>) option.
+=item * B<entry> => I<str_or_re>
 
-Default formatters are best specified in the configuration as opposed to on the
+Find entry by string or regex search against its title.
+
+=item * B<field_value_formatter_rules> => I<array[hash]>
+
+Specify field value formatters to use when conditions are met, specified as an
+array of hashes. Each element is a rule that is as a hash containing condition
+keys and formatters keys. If all conditions are met then the formatters will be
+applied. The rules will be tested when each field is about to be outputted.
+Multiple rules can match and the matching rules' formatters are all applied in
+succession.
+
+Note that this option will be overridden by the C<--field-value-formatter>
+(C<-fvfmt>) or the C<--no-field-value-formatters> (C<-F>) option.
+
+The rules are best specified in the configuration as opposed to on the
 command-line option. An example (the lines below are writen in configuration
 file in IOD syntax, as rows of JSON hashes):
 
  ; by default remove all comments in field values when 'hide_field_name'
  ; option is set (which usually means we want to copy paste things)
- default_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
+ field_value_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
  
  ; by default normalize phone numbers using Phone::format_phone_idn_nospace
  ; when 'hide_field_name' option is set (which usually means we want to copy
  ; paste things). e.g. '0812-1234-5678' becomes '+6281212345678'.
- default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+ field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
  
  ; but if 'hide_field_name' field is not set, normalize phone numbers using
  ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
  ; 5678').
- default_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
+ field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
 
 Condition keys:
 
@@ -259,13 +268,27 @@ specifying formatter.
 
 =back
 
-=item * B<detail> => I<bool>
+=item * B<field_value_formatters> => I<array[str]>
 
-(No description)
+Add one or more formatters to display field value.
 
-=item * B<entry> => I<str_or_re>
+Specify one or more formatters to apply to the field value before displaying.
 
-Find entry by string or regex search against its title.
+A formatter is name of C<Data::Sah::Filter::perl::*> module, without the prefix.
+For example: C<Str::uc> will convert the field value to uppercase. Another
+formatter, C<Str::remove_comment> can remove comment.
+
+A formatter can have arguments, which is specified using this format:
+
+ [FORMATTER_NAME, {ARG1NAME => ARG1VAL, ...}]
+
+If formatter name begins with C<[> character, it will be parsed as JSON. Example:
+
+ ['Str::remove_comment', {'style':'cpp'}]
+
+Note that this option overrides C<--field-value-formatter-rules> but is
+overridden by the C<--no-field-value-formatters> (C<--raw-field-values>, C<-F>)
+option.
 
 =item * B<fields> => I<array[str_or_re]>
 
@@ -288,27 +311,6 @@ That is, it can search for a string (C<str>) or regex (C<re>) in the field name,
 and optionally also search for a string (C<str2>) or regex (C<re2>) in the field
 value.
 
-=item * B<formatters> => I<array[str]>
-
-Add one or more formatters to display field value.
-
-Specify one or more formatters to apply to the field value before displaying.
-
-A formatter is name of C<Data::Sah::Filter::perl::*> module, without the prefix.
-For example: C<Str::uc> will convert the field value to uppercase. Another
-formatter, C<Str::remove_comment> can remove comment.
-
-A formatter can have arguments, which is specified using this format:
-
- [FORMATTER_NAME, {ARG1NAME => ARG1VAL, ...}]
-
-If formatter name begins with C<[> character, it will be parsed as JSON. Example:
-
- ['Str::remove_comment', {'style':'cpp'}]
-
-Note that this option overrides C<--default-formatter-rules> but is overridden by
-the C<--no-formatters> (C<--raw-field-values>, C<-F>) option.
-
 =item * B<hide_category> => I<true>
 
 Do not show category.
@@ -321,12 +323,13 @@ Do not show entry headline.
 
 Do not show field names, just show field values.
 
-=item * B<no_formatters> => I<true>
+=item * B<no_field_value_formatters> => I<true>
 
-Do not apply any formatters to field value (overrides --formatter option).
+Do not apply formatters for field value (overrides --field-value-formatter option).
 
-Note that this option has higher precedence than C<--default-formatter-rules> or
-the C<--formatter> option.
+Note that this option has higher precedence than
+C<--default-field-value-formatter-rules> or the C<--field-value-formatter>
+(C<--fvfmt>) option.
 
 =item * B<num_entries> => I<uint>
 
